#
# spec file for package umockdev
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib libumockdev0
%define shlibpre libumockdev-preload0
Name:           umockdev
Version:        0.17.18
Release:        bp156.1.1
Summary:        Mock hardware devices for creating unit tests and bug reporting
License:        LGPL-2.1-or-later
URL:            https://github.com/martinpitt/umockdev/
Source:         https://github.com/martinpitt/umockdev/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
# Disable to avoid build cycle with gudev (it is recommended but not required here)
# BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libpcap)
BuildRequires:  pkgconfig(libudev)
# For tests
BuildRequires:  pkgconfig(udev)

%description
umockdev mocks Linux devices for creating integration tests for hardware
related libraries and programs. It also provides tools to record the properties
and behaviour of particular devices, and to run a program or test suite under a
test bed with the previously recorded devices loaded.

%package -n %{shlib}
Summary:        Shared library for umockdev

%description -n %{shlib}
umockdev mocks Linux devices for creating integration tests for hardware
related libraries and programs.

This package provides the shared library for %{name}.

%package -n %{shlibpre}
Summary:        Shared library for umockdev-preload

%description -n %{shlibpre}
umockdev mocks Linux devices for creating integration tests for hardware
related libraries and programs.

This package provides the shared library for umockdev-preload.

%package devel
Summary:        Headers and sources for developing apps with umockdev
Requires:       %{name} = %{version}
Requires:       %{shlibpre} = %{version}
Requires:       %{shlib} = %{version}
Requires:       typelib-1_0-UMockdev-1_0 = %{version}

%description devel
umockdev mocks Linux devices for creating integration tests for hardware
related libraries and programs.

This package provides the headers and sources needed to build software against
umockdev.

%package -n typelib-1_0-UMockdev-1_0
Summary:        Introspection bindings for umockdev -- a hardware mocking tool

%description -n typelib-1_0-UMockdev-1_0
umockdev mocks Linux devices for creating integration tests for hardware
related libraries and programs.

This package provides the GObject Introspection bindings for the library
umockdev.

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig
%post -n %{shlibpre} -p /sbin/ldconfig
%postun -n %{shlibpre} -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/*

%files -n %{shlib}
%license COPYING
%{_libdir}/libumockdev.so.*

%files -n %{shlibpre}
%license COPYING
%{_libdir}/libumockdev-preload.so.*

%files devel
%license COPYING
%{_includedir}/umockdev-1.0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/*.vapi

%files -n typelib-1_0-UMockdev-1_0
%{_libdir}/girepository-1.0/UMockdev-1.0.typelib

%changelog
* Thu Sep  7 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.18:
  * Fix some potential crashes spotted by Coverity.
* Fri Apr 21 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.17:
  * Fix uevent race condition in
    umockdev_testbed_add_from_string().
* Tue Feb 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.16:
  * preload: Wrap __getcwd_chk().
  * uevent_sender: Fix fd leak in sendmsg_one.
  * Fix gcc -fanalyzer complaints.
* Sun Nov 27 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.15:
  * Fixes for tests.
- Changes from version 0.17.14:
  * ioctl: Make data object usable from Python.
  * preload: Wrap statfs().
  * Move to gnu11 C standard.
  * Lots of small potential bug fixes spotted by Coverity.
* Fri Jun 24 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 0.17.13:
  * preload: Wrap fstatfs(), to work with systemd 251 also with Python tests
  * Fix tests in Gentoo sandbox build
* Sun May 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.12:
  * Work around packit propose_downstream bug.
* Mon Apr 11 2022 Martin Liška <mliska@suse.cz>
- Update to version 0.17.9:
  * preload: Wrap fortified version of readlinkat (thanks Martin
    Liska)
* Sat Mar 26 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.8:
  * Fix some potential crashes spotted by Coverity.
- Change from version 0.17.7:
  * Fix uevent race condition in
    umockdev_testbed_add_from_string().
* Tue Feb  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.6:
  * Increase uevent buffer size (gh#martinpitt/umockdev#167).
  * Skip /umockdev-testbed-vala/detects_running_outside_testbed
    during normal builds for the time being, as it is brittle on
    several architectures (gh#martinpitt/umockdev#169).
* Sat Jan 29 2022 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: this allows OBS to
  properly shotcut through the -mini flavors.
* Wed Jan 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.5:
  * Relax overzealous stat nlink unit test.
- Changes from versions 0.17.2 through to 0.17.4:
  * Include udev properties in emulated netlink messages, to work
    with recent libudev (gh#martinpitt/umockdev#165).
  * tests: Work around broken HIDIOCGRDESCSIZE ioctl on big-endian
    architectures.
  * preload: Wrap statx() and fstatat(), to fix ls and other tools
    on recent glibc versions (gh#martinpitt/umockdev#160).
- Enable tests in a %%check section; add BuildRequires: udev,
  required for tests.
* Fri Dec 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.17.1:
  * Fix /sys/dev/* symlinks; regression from 0.15.3
    (gh#martinpitt/umockdev#155).
- Changes from version 0.17.0:
  * Add ioctls necessary to record/replay hidraw devices.
  * meson: Respect includedir option.
  * tests: Fix for Fedora koji emulated architectures s390x and
    arm.
* Fri Sep 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add umocdev Requires to devel sub-package, packages using
  umockdev-devel during build expects the binaries to be available.
* Wed Sep 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.16.3:
  * Several pcap replay fixes.
  * Immediately create "bus" and "class" directories in /sys to
    fix udev enumerator (gh#martinpitt/umockdev#144).
  * preload: Avoid some unaligned access to fix failure on sparc
    (gh#martinpitt/umockdev#147).
  * Fix build on Alpine.
  * Don't build with -Werror by default; use meson setup --werror
    to re-enable.
* Mon Sep 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable to avoid build cycle with gudev (it is recommended but
  not required for umockdev itself).
* Thu Aug 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.16.2:
  * Implement pcap control transfer replaying.
  * Fix Coverity errors.
  * Fix most valac build warnings.
- Changes from version 0.16.1:
  * Fix wrong ioctl constants on ppc64el.
  * Fix test-umockdev-record failure in some build environments.
- Changes from version 0.16.0:
  * Move ioctl emulation from preload library to main test
    process.
  * Add test API for custom ioctl and device read/write handlers
    (gh#martinpitt/umockdev#96, gh#martinpitt/umockdev#128).
  * Support USB replay from usbmon pcap captures
    (gh#martinpitt/umockdev#82, gh#martinpitt/umockdev#117).
  * Support SPI ioctl/read/write record and replay
    (gh#martinpitt/umockdev#121).
- New upstream BuildRequires: pkgconfig(libpcap).
* Sat May  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.15.5:
  * Fix build with vala 0.52.
  * Fix build on 32 bit Alpine.
* Tue Jan  5 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
